@@ -3,5 +3,5 @@
 reV-SAM interface module
 """
 from .econ import LCOE, SingleOwner
-from .generation import Pvwattsv5, Pvwattsv7, TcsMoltenSalt, WindPower
+from .generation import PvWattsv5, PvWattsv7, PvSamv1, TcsMoltenSalt, WindPower
 from .windbos import WindBos
