@@ -61,7 +61,7 @@ def from_config(ctx, config_file, points_range, verbose):
               else BespokeConfig(config_file))
 
     verbose = config.log_level == logging.DEBUG
-    verbose = any([verbose, ctx.obj['VERBOSE']])
+    ctx.obj['VERBOSE'] = verbose = any([verbose, ctx.obj['VERBOSE']])
 
     if points_range is not None:
         config['points_range'] = points_range
@@ -88,8 +88,14 @@ def from_config(ctx, config_file, points_range, verbose):
     logger.info('Source exclusion file: "{}"'.format(config.excl_fpath))
     logger.info('Bespoke optimization objective function: "{}"'
                 .format(config.objective_function))
-    logger.info('Bespoke optimization cost function: "{}"'
-                .format(config.cost_function))
+    logger.info('Bespoke capital cost function: "{}"'
+                .format(config.capital_cost_function))
+    logger.info('Bespoke fixed operating cost function: "{}"'
+                .format(config.fixed_operating_cost_function))
+    logger.info('Bespoke variable operating cost function: "{}"'
+                .format(config.variable_operating_cost_function))
+    logger.info('Bespoke wake loss multiplier: "{}"'
+                .format(config.wake_loss_multiplier))
     logger.info('The following project points were specified with '
                 'points_range "{}": "{}"'
                 .format(config.points_range, config.project_points))
@@ -105,12 +111,17 @@ def from_config(ctx, config_file, points_range, verbose):
     ctx.obj['RES_FPATH'] = config.res_fpath
     ctx.obj['TM_DSET'] = config.tm_dset
     ctx.obj['OBJECTIVE_FUNCTION'] = config.objective_function
-    ctx.obj['COST_FUNCTION'] = config.cost_function
+    ctx.obj['CAPITAL_COST_FUNCTION'] = config.capital_cost_function
+    ctx.obj['FIXED_OPERATING_COST_FUNCTION'] = \
+        config.fixed_operating_cost_function
+    ctx.obj['VARIABLE_OPERATING_COST_FUNCTION'] = \
+        config.variable_operating_cost_function
     ctx.obj['POINTS'] = config.project_points
     ctx.obj['POINTS_RANGE'] = config.points_range
     ctx.obj['SAM_FILES'] = config.sam_files
     ctx.obj['MIN_SPACING'] = config.min_spacing
-    ctx.obj['GA_TIME'] = config.ga_time
+    ctx.obj['WAKE_LOSS_MULTIPLIER'] = config.wake_loss_multiplier
+    ctx.obj['GA_KWARGS'] = config.ga_kwargs
     ctx.obj['OUTPUT_REQUEST'] = config.output_request
     ctx.obj['WS_BINS'] = config.ws_bins
     ctx.obj['WD_BINS'] = config.wd_bins
@@ -119,6 +130,7 @@ def from_config(ctx, config_file, points_range, verbose):
     ctx.obj['MIN_AREA'] = config.min_area
     ctx.obj['RESOLUTION'] = config.resolution
     ctx.obj['EXCL_AREA'] = config.excl_area
+    ctx.obj['DATA_LAYERS'] = config.data_layers
     ctx.obj['PRE_EXTRACT_INCLUSIONS'] = config.pre_extract_inclusions
 
     ctx.obj['LOG_DIR'] = config.log_directory
@@ -172,33 +184,38 @@ def from_config(ctx, config_file, points_range, verbose):
                 Status.add_job(config.dirout, ModuleName.BESPOKE,
                                name, replace=True,
                                job_attrs=job_attrs)
-                max_workers = config.execution_control.max_workers
-                pre_extract_inclusions = config.pre_extract_inclusions
-                ctx.invoke(direct,
-                           excl_fpath=config.excl_fpath,
-                           res_fpath=config.res_fpath,
-                           out_fpath=out_fpath,
-                           tm_dset=config.tm_dset,
-                           objective_function=config.objective_function,
-                           cost_function=config.cost_function,
-                           points=config.project_points,
-                           sam_files=config.sam_files,
-                           points_range=config.points_range,
-                           min_spacing=config.min_spacing,
-                           ga_time=config.ga_time,
-                           output_request=config.output_request,
-                           ws_bins=config.ws_bins,
-                           wd_bins=config.wd_bins,
-                           excl_dict=config.excl_dict,
-                           area_filter_kernel=config.area_filter_kernel,
-                           min_area=config.min_area,
-                           resolution=config.resolution,
-                           excl_area=config.excl_area,
-                           log_dir=config.log_directory,
-                           max_workers=max_workers,
-                           pre_extract_inclusions=pre_extract_inclusions,
-                           verbose=verbose,
-                           )
+                kws = {'excl_fpath': config.excl_fpath,
+                       'res_fpath': config.res_fpath,
+                       'out_fpath': out_fpath,
+                       'tm_dset': config.tm_dset,
+                       'objective_function':
+                           config.objective_function,
+                       'capital_cost_function':
+                           config.capital_cost_function,
+                       'fixed_operating_cost_function':
+                           config.fixed_operating_cost_function,
+                       'variable_operating_cost_function':
+                           config.variable_operating_cost_function,
+                       'points': config.project_points,
+                       'sam_files': config.sam_files,
+                       'points_range': config.points_range,
+                       'min_spacing': config.min_spacing,
+                       'wake_loss_multiplier': config.wake_loss_multiplier,
+                       'ga_kwargs': config.ga_kwargs,
+                       'output_request': config.output_request,
+                       'ws_bins': config.ws_bins,
+                       'wd_bins': config.wd_bins,
+                       'excl_dict': config.excl_dict,
+                       'area_filter_kernel': config.area_filter_kernel,
+                       'min_area': config.min_area,
+                       'resolution': config.resolution,
+                       'excl_area': config.excl_area,
+                       'log_dir': config.log_directory,
+                       'max_workers': config.execution_control.max_workers,
+                       'data_layers': config.data_layers,
+                       'pre_extract_inclusions': config.pre_extract_inclusions,
+                       'verbose': verbose}
+                ctx.invoke(direct, **kws)
 
         elif config.execution_control.option in ('eagle', 'slurm'):
             stdout_path = os.path.join(config.log_directory, 'stdout')
@@ -241,17 +258,27 @@ def valid_config_keys():
               '- n_turbines: the number of turbines'
               '- system_capacity: wind plant capacity'
               '- aep: annual energy production'
-              '- self.wind_plant: the SAM wind plant object, through which'
-              'all SAM variables can be accessed'
-              '- cost: the annual cost of the wind plant')
-@click.option('--cost_function', '-cos', required=True, type=STR,
-              help='The cost function as a string, returns the annual cost'
-              'of the wind farm. Variables available are:'
-              '- n_turbines: the number of turbines'
-              '- system_capacity: wind plant capacity'
-              '- aep: annual energy production'
+              '- fixed_charge_rate: user input if included in sam sys config'
+              '- capital_cost: the cap cost output by the cap cost function'
+              '- fixed_operating_cost: the foc output by the foc function'
+              '- variable_operating_cost: the voc output by the voc function'
               '- self.wind_plant: the SAM wind plant object, through which'
               'all SAM variables can be accessed')
+@click.option('--capital_cost_function', '-cc',
+              required=True, type=STR,
+              help='The plant capital cost function as a string, must return '
+              'the total capital cost in $. Has access to the same variables '
+              'as the objective_function.')
+@click.option('--fixed_operating_cost_function', '-foc',
+              required=True, type=STR,
+              help='The plant annual fixed operating cost function as a '
+              'string, must return the fixed operating cost in $/year. Has '
+              'access to the same variables as the objective_function.')
+@click.option('--variable_operating_cost_function', '-voc',
+              required=True, type=STR,
+              help='The plant annual variable operating cost function as a '
+              'string, must return the variable operating cost in $/kWh. Has '
+              'access to the same variables as the objective_function.')
 @click.option('--points', '-p',
               default=None, type=SCPOINTS, show_default=True,
               help='Project points to analyze. This can either be a string '
@@ -272,9 +299,20 @@ def valid_config_keys():
               help='Minimum spacing between turbines in meters. Can also be '
               'a string like "5x" (default) which is interpreted as 5 times '
               'the turbine rotor diameter.')
-@click.option('--ga_time', '-ga', default=20, type=FLOAT, show_default=True,
-              help='Cutoff time for single-plant genetic algorithm '
-              'optimization in seconds.')
+@click.option('--wake_loss_multiplier', '-wlm', type=FLOAT, default=1,
+              show_default=True,
+              help='A multiplier used to scale the annual energy lost due to '
+              'wake losses. **IMPORTANT**: This multiplier will ONLY be '
+              'applied during the optimization process and will NOT be '
+              'come through in output values such as hourly generation '
+              'profiles, aep, any of the cost functions, or even the output '
+              'objective.')
+@click.option('--ga_kwargs', '-gakw', type=STR, default=None,
+              show_default=True,
+              help='Dictionary of keyword arguments to pass to GA '
+              'initialization.If `None`, default initialization values are '
+              'used. See the reV.bespoke.gradient_free.GeneticAlgorithm class '
+              'for a description of the allowed keyword arguments.')
 @click.option('--output_request', '-or', type=STRLIST,
               default=['cf_mean', 'system_capacity'], show_default=True,
               help=('List of requested output variable names from SAM.'))
@@ -297,9 +335,10 @@ def valid_config_keys():
               help='String representation of a dictionary of exclusion '
               'LayerMask arguments {layer: {kwarg: value}} where layer '
               'is a dataset in excl_fpath and kwarg can be '
-              '"inclusion_range", "exclude_values", "include_values", '
-              '"inclusion_weights", "force_inclusion_values", '
-              '"use_as_weights", "exclude_nodata", and/or "weight".')
+              '"exclude_values", "exclude_range", "include_values", '
+              '"include_range", "include_weights", "force_include_values", '
+              '"force_include_range", "use_as_weights", "weight", '
+              '"exclude_nodata", and/or "nodata_value".')
 @click.option('--area_filter_kernel', '-afk', type=STR, default='queen',
               show_default=True,
               help='Contiguous area filter kernel name ("queen", "rook").')
@@ -321,6 +360,12 @@ def valid_config_keys():
 @click.option('--max_workers', '-mw', type=INT, default=None,
               show_default=True,
               help='Number of workers. Use 1 for serial, None for all cores.')
+@click.option('--data_layers', '-d', type=STR, default=None,
+              show_default=True,
+              help='String representation of a dictionary of additional data '
+              'layers to include in the aggregation e.g. '
+              '{"slope": {"dset": "srtm_slope", "method": "mean", '
+              '"fpath": "./excl.h5"}}')
 @click.option('-pre', '--pre_extract_inclusions', is_flag=True,
               help='Optional flag to pre-extract/compute the inclusion mask '
               'from the provided excl_dict, by default False. Typically '
@@ -330,22 +375,28 @@ def valid_config_keys():
               help='Flag to turn on debug logging. Default is not verbose.')
 @click.pass_context
 def direct(ctx, excl_fpath, res_fpath, out_fpath, tm_dset, objective_function,
-           cost_function, points, sam_files, points_range, min_spacing,
-           ga_time, output_request, ws_bins, wd_bins, excl_dict,
-           area_filter_kernel, min_area, resolution, excl_area,
-           log_dir, max_workers, pre_extract_inclusions, verbose):
+           capital_cost_function, fixed_operating_cost_function,
+           variable_operating_cost_function, points, sam_files, points_range,
+           min_spacing, wake_loss_multiplier, ga_kwargs, output_request,
+           ws_bins, wd_bins, excl_dict, area_filter_kernel, min_area,
+           resolution, excl_area, log_dir, max_workers, data_layers,
+           pre_extract_inclusions, verbose):
     """Run reV Bespoke directly w/o a config file."""
     ctx.obj['EXCL_FPATH'] = excl_fpath
     ctx.obj['RES_FPATH'] = res_fpath
     ctx.obj['OUT_FPATH'] = out_fpath
     ctx.obj['TM_DSET'] = tm_dset
     ctx.obj['OBJECTIVE_FUNCTION'] = objective_function
-    ctx.obj['COST_FUNCTION'] = cost_function
+    ctx.obj['CAPITAL_COST_FUNCTION'] = capital_cost_function
+    ctx.obj['FIXED_OPERATING_COST_FUNCTION'] = fixed_operating_cost_function
+    ctx.obj['VARIABLE_OPERATING_COST_FUNCTION'] = \
+        variable_operating_cost_function
     ctx.obj['POINTS'] = points
     ctx.obj['POINTS_RANGE'] = points_range
     ctx.obj['SAM_FILES'] = sam_files
     ctx.obj['MIN_SPACING'] = min_spacing
-    ctx.obj['GA_TIME'] = ga_time
+    ctx.obj['WAKE_LOSS_MULTIPLIER'] = wake_loss_multiplier
+    ctx.obj['GA_KWARGS'] = ga_kwargs
     ctx.obj['OUTPUT_REQUEST'] = output_request
     ctx.obj['WS_BINS'] = ws_bins
     ctx.obj['WD_BINS'] = wd_bins
@@ -354,6 +405,7 @@ def direct(ctx, excl_fpath, res_fpath, out_fpath, tm_dset, objective_function,
     ctx.obj['MIN_AREA'] = min_area
     ctx.obj['RESOLUTION'] = resolution
     ctx.obj['EXCL_AREA'] = excl_area
+    ctx.obj['DATA_LAYERS'] = data_layers
     ctx.obj['PRE_EXTRACT_INCLUSIONS'] = pre_extract_inclusions
     ctx.obj['LOG_DIR'] = log_dir
     verbose = any([verbose, ctx.obj['VERBOSE']])
@@ -372,20 +424,30 @@ def direct(ctx, excl_fpath, res_fpath, out_fpath, tm_dset, objective_function,
                     'resource file: {}. Target output path is: {}'
                     .format(name, res_fpath, out_fpath))
 
+        if isinstance(data_layers, str):
+            data_layers = dict_str_load(data_layers)
+
         if isinstance(excl_dict, str):
             excl_dict = dict_str_load(excl_dict)
 
+        if isinstance(ga_kwargs, str):
+            ga_kwargs = dict_str_load(ga_kwargs)
+
         t0 = time.time()
 
         try:
             # Execute the Bespoke module with smart data flushing.
             BespokeWindPlants.run(
                 excl_fpath, res_fpath, tm_dset,
-                objective_function, cost_function,
+                objective_function,
+                capital_cost_function,
+                fixed_operating_cost_function,
+                variable_operating_cost_function,
                 points, sam_files,
                 points_range=points_range,
                 min_spacing=min_spacing,
-                ga_time=ga_time,
+                wake_loss_multiplier=wake_loss_multiplier,
+                ga_kwargs=ga_kwargs,
                 output_request=output_request,
                 ws_bins=ws_bins,
                 wd_bins=wd_bins,
@@ -394,6 +456,7 @@ def direct(ctx, excl_fpath, res_fpath, out_fpath, tm_dset, objective_function,
                 min_area=min_area,
                 resolution=resolution,
                 excl_area=excl_area,
+                data_layers=data_layers,
                 pre_extract_inclusions=pre_extract_inclusions,
                 max_workers=max_workers,
                 out_fpath=out_fpath)
@@ -416,7 +479,12 @@ def direct(ctx, excl_fpath, res_fpath, out_fpath, tm_dset, objective_function,
                   'runtime': runtime, 'res_fpath': res_fpath,
                   'excl_fpath': excl_fpath, 'tm_dset': tm_dset,
                   'objective_function': objective_function,
-                  'cost_function': cost_function, 'excl_dict': excl_dict}
+                  'capital_cost_function': capital_cost_function,
+                  'fixed_operating_cost_function':
+                      fixed_operating_cost_function,
+                  'variable_operating_cost_function':
+                      variable_operating_cost_function,
+                  'excl_dict': excl_dict}
         Status.make_job_file(out_dir, ModuleName.BESPOKE, name, status)
 
 
@@ -430,12 +498,15 @@ def get_node_cmd(name, kwargs):
         '-of {}'.format(SLURM.s(kwargs['OUT_FPATH'])),
         '-tm {}'.format(SLURM.s(kwargs['TM_DSET'])),
         '-obj {}'.format(SLURM.s(kwargs['OBJECTIVE_FUNCTION'])),
-        '-cos {}'.format(SLURM.s(kwargs['COST_FUNCTION'])),
+        '-cc {}'.format(SLURM.s(kwargs['CAPITAL_COST_FUNCTION'])),
+        '-foc {}'.format(SLURM.s(kwargs['FIXED_OPERATING_COST_FUNCTION'])),
+        '-voc {}'.format(SLURM.s(kwargs['VARIABLE_OPERATING_COST_FUNCTION'])),
         '-p {}'.format(SLURM.s(kwargs['POINTS'])),
         '-sf {}'.format(SLURM.s(kwargs['SAM_FILES'])),
         '-pr {}'.format(SLURM.s(kwargs['POINTS_RANGE'])),
         '-ms {}'.format(SLURM.s(kwargs['MIN_SPACING'])),
-        '-ga {}'.format(SLURM.s(kwargs['GA_TIME'])),
+        '-wlm {}'.format(SLURM.s(kwargs['WAKE_LOSS_MULTIPLIER'])),
+        '-gakw {}'.format(SLURM.s(kwargs['GA_KWARGS'])),
         '-or {}'.format(SLURM.s(kwargs['OUTPUT_REQUEST'])),
         '-ws {}'.format(SLURM.s(kwargs['WS_BINS'])),
         '-wd {}'.format(SLURM.s(kwargs['WD_BINS'])),
@@ -444,6 +515,7 @@ def get_node_cmd(name, kwargs):
         '-ma {}'.format(SLURM.s(kwargs['MIN_AREA'])),
         '-r {}'.format(SLURM.s(kwargs['RESOLUTION'])),
         '-ea {}'.format(SLURM.s(kwargs['EXCL_AREA'])),
+        '-d {}'.format(SLURM.s(kwargs['DATA_LAYERS'])),
         '-lo {}'.format(SLURM.s(kwargs['LOG_DIR'])),
         '-mw {}'.format(SLURM.s(kwargs['MAX_WORKERS']))]
 
